Class: Locomotive::Wagon::CloneCommand
- Inherits:
-
Struct
- Object
- Struct
- Locomotive::Wagon::CloneCommand
- Defined in:
- lib/locomotive/wagon/commands/clone_command.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
Returns the value of attribute name.
-
#options ⇒ Object
Returns the value of attribute options.
-
#path ⇒ Object
Returns the value of attribute path.
-
#shell ⇒ Object
Returns the value of attribute shell.
Class Method Summary collapse
Instance Method Summary collapse
Instance Attribute Details
#name ⇒ Object
Returns the value of attribute name
6 7 8 |
# File 'lib/locomotive/wagon/commands/clone_command.rb', line 6 def name @name end |
#options ⇒ Object
Returns the value of attribute options
6 7 8 |
# File 'lib/locomotive/wagon/commands/clone_command.rb', line 6 def @options end |
#path ⇒ Object
Returns the value of attribute path
6 7 8 |
# File 'lib/locomotive/wagon/commands/clone_command.rb', line 6 def path @path end |
#shell ⇒ Object
Returns the value of attribute shell
6 7 8 |
# File 'lib/locomotive/wagon/commands/clone_command.rb', line 6 def shell @shell end |
Class Method Details
.clone(name, path, options, shell) ⇒ Object
8 9 10 |
# File 'lib/locomotive/wagon/commands/clone_command.rb', line 8 def self.clone(name, path, , shell) new(name, path, , shell).clone end |
Instance Method Details
#clone ⇒ Object
12 13 14 15 16 17 18 |
# File 'lib/locomotive/wagon/commands/clone_command.rb', line 12 def clone # create an empty site with the minimal settings create_site # pull the pages, content_types, basically any resources from the remote site pull_site end |
#connection_info ⇒ Object
20 21 22 |
# File 'lib/locomotive/wagon/commands/clone_command.rb', line 20 def connection_info .symbolize_keys.slice(:host, :handle, :email, :api_key, :password) end |